#!/usr/bin/env python

from distutils.core import setup
import os

setup(name='touchsearch-quickbar',
   version='1.0',
   data_files = [
      ('/opt/touchsearch/search_engines/QuickBar/',['QuickBar.search', 'quickbar_color.png', 'quickbar_ghosted.png'])
      ]
      )